Learn R Programming

Lahman (version 2.0-3)

Lahman-package: Sean Lahman's Baseball Database

Description

This database contains pitching, hitting, and fielding statistics for Major League Baseball from 1871 through 2012. It includes data from the two current leagues (American and National), the four other "major" leagues (American Association, Union Association, Players League, and Federal League), and the National Association of 1871-1875.

This database was created by Sean Lahman, who pioneered the effort to make baseball statistics freely available to the general public. What started as a one man effort in 1994 has grown tremendously, and now a team of researchers have collected their efforts to make this the largest and most accurate source for baseball statistics available anywhere.

This database, in the form of an R package offers a variety of interesting challenges and opportunities for data processing and visualization in R.

Arguments

tabular

  • rl
  • rl
  • rl
  • rl

tab

source

Lahman, S. (2012) Lahman's Baseball Database, 1871-2012, Main page, http://baseball1.com/statistics/

Lahman, S. (2012) Lahman's Baseball Database, 1871-2012, v. 2012, Comma-delimited version, http://seanlahman.com/files/database/lahman2012-csv.zip

Lahman, S. (2012) Lahman's Baseball Database, 1871-2012, MS Access version, http://seanlahman.com/files/database/lahman2012-ms.zip

Details

ll{ Package: Lahman Type: Package Version: 2.0-3 Date: 2013-05-29 License: GPL version 2 or newer LazyLoad: yes LazyData: yes }

The main form of this database is a relational database in Microsoft Access format. The design follows these general principles. Each player is assigned a unique code (playerID). All of the information in different tables relating to that player is tagged with his playerID. The playerIDs are linked to names and birthdates in the Master table. Similar links exist among other tables via analogous *ID variables.

The database is comprised of the following main tables:

[object Object],[object Object],[object Object],[object Object]