battingStats: Calculcate additional batting statistics
Description
The Batting does not contain batting statistics derived from those
present in the data.frame. This function calculates
batting average (BA),
plate appearances (PA),
total bases (TB),
slugging percentage (SlugPct),
on-base percentage (OBP),
on-base percentage + slugging (OPS), and
batting average on balls in play (BABIP)
for each record in a Batting-like data.frame.Usage
battingStats(data = Batting, idvars = c("playerID", "yearID", "stint", "teamID", "lgID"),
cbind = TRUE)Arguments
idvars
ID variables to include in the output data.frame
cbind
If TRUE, the calculated statistics are appended to the input data as additional columns
Value
- A data.frame with all the observations in
data.
If cbind==FALSE, only the idvars and the calculated variables are returned.
Details
Standard calculations, e.g., BA <- H/AB are problematic because of the
presence of NAs and zeros. This function tries to deal with those
problems.Examples
Run this codebstats <- battingStats()
str(bstats)
bstats <- battingStats(cbind=FALSE)
str(bstats)
Run the code above in your browser using DataLab